@@ -35,40 +35,12 @@
  */
 
 #include "toolbox.h"
+#include "toolbox-internal.h"
 
 void
 gm_open_uri (const gchar *uri)
 {
-  gchar *commandline = NULL;
-  gboolean success = FALSE;
-
   g_return_if_fail (uri != NULL);
 
-  if (!success && g_getenv("KDE_FULL_SESSION") != NULL) {
-
-    commandline = g_strdup_printf ("kfmclient exec %s", uri);
-    success = g_spawn_command_line_async (commandline, NULL);
-    g_free (commandline);
-  }
-
-  if (!success) {
-
-    commandline = g_strdup_printf ("sensible-browser %s", uri);
-    success = g_spawn_command_line_async (commandline, NULL);
-    g_free (commandline);
-  }
-
-  if (!success) {
-
-    commandline = g_strdup_printf ("firefox %s", uri);
-    success = g_spawn_command_line_async (commandline, NULL);
-    g_free (commandline);
-  }
-
-  if (!success) {
-
-    commandline = g_strdup_printf ("konqueror %s", uri);
-    success = g_spawn_command_line_async (commandline, NULL);
-    g_free (commandline);
-  }
+  gm_open_uri_fallback (uri);
 }
