@@ -41,39 +41,7 @@
 #define _PREFERENCES_H_
 
 #include "common.h"
-
-
-/* DESCRIPTION  :  /
- * BEHAVIOR     :  Refreshes the interfaces list in the GUI to update them from
- *                 the GnomeMeeting available list.
- * PRE          :  The prefs window GMObject, the available devices list.
- */
-void gm_prefs_window_update_interfaces_list (GtkWidget *prefs_window,
-					     PStringArray interfaces);
-
-/* DESCRIPTION  :  /
- * BEHAVIOR     :  Refreshes the devices list in the GUI to update them from
- *                 the GnomeMeeting available devices list.
- * PRE          :  The prefs window GMObject, the audio input devices list,
- * 		   the audio output devices list, the video input devices list.
- */
-void gm_prefs_window_update_devices_list (GtkWidget *prefs_window,
-					  PStringArray audio_input_devices,
-					  PStringArray audio_output_devices,
-					  PStringArray video_input_devices);
-
-/* DESCRIPTION  :  /
- * BEHAVIOR     :  Refreshes the codecs list in the GUI to update them from
- *                 the given OpalMediaFormat list. Do it following the user 
- *                 configuration. The list is presented to the user using the 
- *                 short form (e.g. "PCMU") and not the long form (e.g.
- *                 "G.711-uLaw-64k") even though the configuration is supposed
- *                 to store the long form.
- * PRE          :  /
- */
-void gm_prefs_window_update_audio_codecs_list (GtkWidget *prefs_window,
-					       OpalMediaFormatList &l);
-
+#include "framework/services.h"
 
 /* DESCRIPTION  :  / 
  * BEHAVIOR     :  Builds the sound events list of the preferences window. 
@@ -88,7 +56,7 @@ void gm_prefs_window_sound_events_list_build (GtkWidget *prefs_window);
  *                 to appropriate callbacks, then returns it.
  * PRE          :  /
  */
-GtkWidget *gm_prefs_window_new ();
+GtkWidget *gm_prefs_window_new (Ekiga::ServiceCore *core);
 
 
 #endif
